<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://wysylajtaniej.pl
 * @since      1.0.0
 *
 * @package    wysylajtaniej
 * @subpackage wysylajtaniej/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and hooks
 *
 * @package    wysylajtaniej
 * @subpackage wysylajtaniej/public
 * @author     wysylajtaniej.pl <woocommerce@wysylajtaniej.pl>
 */
class wysylajtaniej_Public
{

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string $plugin_name The name of the plugin.
     * @param      string $version The version of this plugin.
     */
    public function __construct($plugin_name, $version)
    {

        $this->plugin_name = $plugin_name;
        $this->version = $version;

    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles()
    {
        if (!is_checkout()) return;
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/wysylajtaniej-public.css', array(), $this->version, 'all');

    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts()
    {
        if (!is_checkout()) return;
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/wysylajtaniej-public.js', array('jquery'), $this->version, false);
        wp_localize_script($this->plugin_name, 'settings', array(
            'ajaxurl' => admin_url('admin-ajax.php'),
            'security' => wysylajtaniej_Admin::getOAuthState(),
        ));

    }

}
